/* vi:set ts=8 sts=0 sw=8:
 *
 * gEdit
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __GE_PREFS_H__
#define __GE_PREFS_H__

extern void gE_save_settings(gE_window *window, gpointer cbwindow);
extern void gE_get_settings(gE_window *window);
extern void gE_rc_parse(void);
extern void prefs_cb(GtkWidget *widget, gpointer cbwindow);

#endif /* __GE_PREFS_H__ */
